@@ -83,6 +83,12 @@
 	worktime.y2014 = {"d0101":2,"d0126":1,"d0131":2,"d0201":2,"d0202":2,"d0203":2,"d0204":2,"d0205":2,"d0206":2,"d0208":1,"d0405":2,"d0407":2,"d0501":2,"d0502":2,"d0503":2,"d0504":1,"d0602":2,"d0908":2,"d0928":1,"d1001":2,"d1002":2,"d1003":2,"d1004":2,"d1005":2,"d1006":2,"d1007":2,"d1011":1};
     worktime.y2015 = {'d0101':2,'d0102':2,'d0103':2,'d0104':1,'d0215':1,'d0218':2,'d0219':2,'d0220':2,'d0221':2,'d0222':2,'d0223':2,'d0224':2,'d0228':1,'d0404':2,'d0405':2,'d0406':2,'d0501':2,'d0502':2,'d0503':2,'d0620':2,'d0621':2,'d0622':2,'d0926':2,'d0927':2,'d1001':2,'d1002':2,'d1003':2,'d1004':2,'d1005':2,'d1006':2,'d1007':2,'d1010':1};
 	
+	worktime.y2018 = {'d0101':2,'d0211':1,'d0215':2,'d0216':2,'d0217':2,'d0218':2,'d0219':2,'d0220':2,'d0221':2,'d0224':1,'d0405':2,'d0406':2,'d0407':2,'d0408':1,'d0428':1,'d0429':2,'d0430':2,'d0501':2,'d0616':2,'d0617':2,'d0618':2,'d0922':2,'d0923':2,'d0924':2,'d0929':1,'d0930':1,'d1001':2,'d1002':2,'d1003':2,'d1004':2,'d1005':2,'d1006':2,'d1007':2,'d1229':1,'d1230':2,'d1231':2};
+
+    	worktime.y2019 = {'d0101':2,'d0202':1,'d0203':1,'d0204':2,'d0205':2,'d0206':2,'d0207':2,'d0208':2,'d0209':2,'d0210':2,'d0405':2,'d0406':2,'d0407':2,'d0501':2,'d0607':2,'d0608':2,'d0609':2,'d0913':2,'d0914':2,'d0915':2,'d0929':1,'d1001':2,'d1002':2,'d1003':2,'d1004':2,'d1005':2,'d1006':2,'d1007':2,'d1012':1};
+
+    	worktime.y2020 = {'d0101':2,'d0102':2,'d0202':1,'d0203':1,'d0204':2,'d0205':2,'d0206':2,'d0207':2,'d0208':2,'d0209':2,'d0210':2,'d0405':2,'d0406':2,'d0407':2,'d0501':2,'d0607':2,'d0608':2,'d0609':2,'d0913':2,'d0914':2,'d0915':2,'d0929':1,'d1001':2,'d1002':2,'d1003':2,'d1004':2,'d1005':2,'d1006':2,'d1007':2,'d1012':1};
+	
 	//公历节日
 	var solarFestival = {
         'd0101':'元旦节',
